==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/az.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "İnformasiya daşıyıcısı mövcud deyil",
    "Storage invalid" : "İnformasiya daşıyıcısı yalnışdır",
    "Unknown error" : "Bəlli olmayan səhv baş verdi",
    "Could not move %s - File with this name already exists" : "Köçürmə mümkün deyil %s - Bu adla fayl artıq mövcuddur",
    "Could not move %s" : "Yerdəyişmə mükün olmadı %s",
    "Permission denied" : "Yetki qadağandır",
    "The target folder has been moved or deleted." : "Mənsəbdə olan qovluqun ünvanı dəyişib yada silinib.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Bu ad %s artıq %s  qovluğunda istifadə edilir. Xahiş olunur fərqli ad istifadə edəsiniz.",
    "Error when creating the file" : "Fayl yaratdıqda səhv baş vermişdir",
    "Error when creating the folder" : "Qovluğu yaratdıqda səhv baş vermişdir",
    "Unable to set upload directory." : "Əlavələr qovluğunu təyin etmək mümkün olmadı.",
    "Invalid Token" : "Yalnış token",
    "No file was uploaded. Unknown error" : "Heç bir fayl uüklənilmədi. Naməlum səhv",
    "There is no error, the file uploaded with success" : "Səhv yoxdur, fayl uğurla yüklənildi.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Yüklənilən faylin həcmi php.ini config faylinin upload_max_filesize direktivində göstəriləndən çoxdur.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "The uploaded file was only partially uploaded" : "Yüklənilən faylın yalnız bir hissəsi yüklənildi",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Failed to write to disk" : "Sərt diskə yazmaq mümkün olmadı",
    "Not enough storage available" : "Tələb edilən qədər yer yoxdur.",
    "Upload failed. Could not find uploaded file" : "Yüklənmədə səhv oldu. Yüklənmiş faylı tapmaq olmur.",
    "Upload failed. Could not get file info." : "Yüklənmədə səhv oldu. Faylın informasiyasını almaq mümkün olmadı.",
    "Invalid directory." : "Yalnış qovluq.",
    "Files" : "Fayllar",
    "All files" : "Bütün fayllar",
    "Favorites" : "Sevimlilər",
    "Home" : "Ev",
    "Close" : "Bağla",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Yükləmək olmur {filename} ona görə ki, ya qovluqdur yada ki, həcmi 0 baytdır ",
    "Total file size {size1} exceeds upload limit {size2}" : "Ümumi fayl həcmi {size1}  yüklənmə limiti {size2} -ni aşır",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Kifayət qədər boş yer yoxdur, siz yükləyirsiniz {size1} ancaq  {size2} var. ",
    "Upload cancelled." : "Yüklənmə dayandırıldı.",
    "Could not get result from server." : "Nəticəni serverdən almaq mümkün olmur.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faylın yüklənməsi gedir. Əgər səhifəni indi tərk etsəniz yüklənmə dayanacaq.",
    "Actions" : "İşlər",
    "Download" : "Yüklə",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Details" : "Detallar",
    "Select" : "Seç",
    "Pending" : "Gözləmə",
    "Unable to determine date" : "Tarixi təyin etmək mümkün olmadı",
    "This operation is forbidden" : "Bu əməliyyat qadağandır",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu qovluq tapılmir. Xahiş olunur jurnalları yoxlayın ya da inzibatçı ilə əlaqə saxlayın",
    "Error moving file." : "Faylın köçürülməsində səhv baş verdi.",
    "Error moving file" : "Faylın köçürülməsində səhv baş verdi",
    "Error" : "Səhv",
    "{new_name} already exists" : "{new_name} artıq mövcuddur",
    "Could not rename file" : "Faylın adını dəyişmək mümkün olmadı",
    "Could not create file" : "Faylı yaratmaq olmur",
    "Could not create folder" : "Qovluğu yaratmaq olmur",
    "Error deleting file." : "Faylın silinməsində səhv baş verdi.",
    "No entries in this folder match '{filter}'" : "Bu qovluqda '{filter}' uyğunluğunda heç bir verilən tapılmadı",
    "Name" : "Ad",
    "Size" : "Həcm",
    "Modified" : "Dəyişdirildi",
    "_%n folder_::_%n folders_" : ["%n qovluq","%n qovluqlar"],
    "_%n file_::_%n files_" : ["%n fayllar","%n fayllar"],
    "{dirs} and {files}" : "{dirs} və {files}",
    "You don’t have permission to upload or create files here" : "Sizin burda yükləməyə və ya fayl yaratmağa yetkiniz yoxdur  ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fayllar yüklənilir","%n fayllar yüklənilir"],
    "New" : "Yeni",
    "\"{name}\" is an invalid file name." : "\"{name}\" yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} məlumat anbarı doludur, fayllar artıq yenilənə və ya sinxronizasiya edilə bilməz!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sizin deponuz doludur, fayllar artıq yenilənə və sinxronizasiya edilə bilməz!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} məlumat anbari demək olar ki, doludur ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Sizin depo depo demək olar ki, doludur ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["uyğun '{filter}'","uyğun '{filter}'"],
    "Path" : "Ünvan",
    "_%n byte_::_%n bytes_" : ["%n baytlar","%n bytes"],
    "Favorited" : "İstəkləndi",
    "Favorite" : "İstəkli",
    "{newname} already exists" : "{newname} artıq mövcuddur",
    "Upload" : "Serverə yüklə",
    "Text file" : "Tekst faylı",
    "New text file.txt" : "Yeni mətn file.txt",
    "Folder" : "Qovluq",
    "New folder" : "Yeni qovluq",
    "An error occurred while trying to update the tags" : "Qeydlərin yenilənməsi müddətində səhv baş verdi ",
    "A new file or folder has been <strong>created</strong>" : "Yeni fayl və ya direktoriya <strong>yaradılmışdır</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fayl və ya direktoriya <strong>dəyişdirilib</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>sevimli faylların</strong> yaradılması və silinməsi haqqında olan xəbərdarlıqları limitlə <em>(Yalnız axınlar)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fayl və ya direktoriya <strong>silinib</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fayl yada qovluq geriyə <strong>qaytarıldı</strong>",
    "You created %1$s" : "Siz yaratdınız %1$s",
    "%2$s created %1$s" : "%2$s yaradılmış %1$s",
    "%1$s was created in a public folder" : "%1$s ictimai qovluqda yaradıldı",
    "You changed %1$s" : "Siz dəyişdiniz %1$s",
    "%2$s changed %1$s" : "%2$s dəyişdirildi %1$s",
    "You deleted %1$s" : "Siz silindiniz %1$s",
    "%2$s deleted %1$s" : "%2$s silindi %1$s",
    "You restored %1$s" : "Siz qayıtdınız %1$s",
    "%2$s restored %1$s" : "%2$s bərpa edildi %1$s",
    "%s could not be renamed as it has been deleted" : "%s adını dəyişə bilmərik ona görə ki, o silinib artıq",
    "%s could not be renamed" : "%s adını dəyişə bilməz",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "File handling" : "Fayl emalı",
    "Maximum upload size" : "Maksimal yükləmə həcmi",
    "max. possible: " : "maks. ola bilər: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "PHP-FPM ilə bu məna yadda saxladıldıqından 5 dəqiqə sonra işə düşə bilər. ",
    "Save" : "Saxlamaq",
    "Can not be edited from here due to insufficient permissions." : "Yetki çatışmamazlığına görə, burdan başlayaraq dəyişiklik edə bilməzsiniz.",
    "Settings" : "Quraşdırmalar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Bu ünvanı <a href=\"%s\" target=\"_blank\">WebDAV vasitəsilə fayllarınızı əldə etmək üçün</a> istifadə edə bilərsiniz. ",
    "Cancel upload" : "Yüklənməni dayandır",
    "No files in here" : "Burda fayl yoxdur",
    "Upload some content or sync with your devices!" : "Bezi kontenti yüklə yada, öz avadanlıqlarınızla sinxronizasiya edin!",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Select all" : "Hamısıı seç",
    "Upload too large" : "Yüklənmə şox böyükdür",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yükləmək istədiyiniz faylların həcmi, bu serverdə izin verilmiş maksimal yüklənmə həcmindən böyükdür.",
    "Files are being scanned, please wait." : "Faylların skanı başlanıb, xahiş olunur gözləyəsiniz.",
    "Currently scanning" : "Hal-hazırda skan edilir",
    "No favorites" : "Seçilmiş yoxdur",
    "Files and folders you mark as favorite will show up here" : "İstəkli qeyd etdiyiniz fayllar və qovluqlar burda göstəriləcək"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/az.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "İnformasiya daşıyıcısı mövcud deyil",
    "Storage invalid" : "İnformasiya daşıyıcısı yalnışdır",
    "Unknown error" : "Bəlli olmayan səhv baş verdi",
    "Unable to set upload directory." : "Əlavələr qovluğunu təyin etmək mümkün olmadı.",
    "Invalid Token" : "Yalnış token",
    "No file was uploaded. Unknown error" : "Heç bir fayl uüklənilmədi. Naməlum səhv",
    "There is no error, the file uploaded with success" : "Səhv yoxdur, fayl uğurla yüklənildi.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Yüklənilən faylin həcmi php.ini config faylinin upload_max_filesize direktivində göstəriləndən çoxdur.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "The uploaded file was only partially uploaded" : "Yüklənilən faylın yalnız bir hissəsi yüklənildi",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Failed to write to disk" : "Sərt diskə yazmaq mümkün olmadı",
    "Not enough storage available" : "Tələb edilən qədər yer yoxdur.",
    "The target folder has been moved or deleted." : "Mənsəbdə olan qovluqun ünvanı dəyişib yada silinib.",
    "Upload failed. Could not find uploaded file" : "Yüklənmədə səhv oldu. Yüklənmiş faylı tapmaq olmur.",
    "Upload failed. Could not get file info." : "Yüklənmədə səhv oldu. Faylın informasiyasını almaq mümkün olmadı.",
    "Invalid directory." : "Yalnış qovluq.",
    "Files" : "Fayllar",
    "All files" : "Bütün fayllar",
    "Favorites" : "Sevimlilər",
    "Home" : "Ev",
    "Close" : "Bağla",
    "Upload cancelled." : "Yüklənmə dayandırıldı.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Yükləmək olmur {filename} ona görə ki, ya qovluqdur yada ki, həcmi 0 baytdır ",
    "Total file size {size1} exceeds upload limit {size2}" : "Ümumi fayl həcmi {size1}  yüklənmə limiti {size2} -ni aşır",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Kifayət qədər boş yer yoxdur, siz yükləyirsiniz {size1} ancaq  {size2} var. ",
    "Could not get result from server." : "Nəticəni serverdən almaq mümkün olmur.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faylın yüklənməsi gedir. Əgər səhifəni indi tərk etsəniz yüklənmə dayanacaq.",
    "Actions" : "İşlər",
    "Download" : "Yüklə",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Disconnect storage" : "Daşıyıcını ayır",
    "Unshare" : "Paylaşımı durdur",
    "Details" : "Detallar",
    "Select" : "Seç",
    "Pending" : "Gözləmə",
    "Unable to determine date" : "Tarixi təyin etmək mümkün olmadı",
    "This operation is forbidden" : "Bu əməliyyat qadağandır",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu qovluq tapılmir. Xahiş olunur jurnalları yoxlayın ya da inzibatçı ilə əlaqə saxlayın",
    "No entries in this folder match '{filter}'" : "Bu qovluqda '{filter}' uyğunluğunda heç bir verilən tapılmadı",
    "Name" : "Ad",
    "Size" : "Həcm",
    "Modified" : "Dəyişdirildi",
    "_%n folder_::_%n folders_" : ["%n qovluq","%n qovluqlar"],
    "_%n file_::_%n files_" : ["%n fayllar","%n fayllar"],
    "{dirs} and {files}" : "{dirs} və {files}",
    "You don’t have permission to upload or create files here" : "Sizin burda yükləməyə və ya fayl yaratmağa yetkiniz yoxdur  ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fayllar yüklənilir","%n fayllar yüklənilir"],
    "New" : "Yeni",
    "\"{name}\" is an invalid file name." : "\"{name}\" yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} məlumat anbarı doludur, fayllar artıq yenilənə və ya sinxronizasiya edilə bilməz!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sizin deponuz doludur, fayllar artıq yenilənə və sinxronizasiya edilə bilməz!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} məlumat anbari demək olar ki, doludur ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Sizin depo depo demək olar ki, doludur ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["uyğun '{filter}'","uyğun '{filter}'"],
    "Path" : "Ünvan",
    "_%n byte_::_%n bytes_" : ["%n baytlar","%n bytes"],
    "Favorited" : "İstəkləndi",
    "Favorite" : "İstəkli",
    "Folder" : "Qovluq",
    "New folder" : "Yeni qovluq",
    "{newname} already exists" : "{newname} artıq mövcuddur",
    "Upload" : "Serverə yüklə",
    "An error occurred while trying to update the tags" : "Qeydlərin yenilənməsi müddətində səhv baş verdi ",
    "A new file or folder has been <strong>created</strong>" : "Yeni fayl və ya direktoriya <strong>yaradılmışdır</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fayl və ya direktoriya <strong>dəyişdirilib</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>sevimli faylların</strong> yaradılması və silinməsi haqqında olan xəbərdarlıqları limitlə <em>(Yalnız axınlar)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fayl və ya direktoriya <strong>silinib</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fayl yada qovluq geriyə <strong>qaytarıldı</strong>",
    "You created %1$s" : "Siz yaratdınız %1$s",
    "%2$s created %1$s" : "%2$s yaradılmış %1$s",
    "%1$s was created in a public folder" : "%1$s ictimai qovluqda yaradıldı",
    "You changed %1$s" : "Siz dəyişdiniz %1$s",
    "%2$s changed %1$s" : "%2$s dəyişdirildi %1$s",
    "You deleted %1$s" : "Siz silindiniz %1$s",
    "%2$s deleted %1$s" : "%2$s silindi %1$s",
    "You restored %1$s" : "Siz qayıtdınız %1$s",
    "%2$s restored %1$s" : "%2$s bərpa edildi %1$s",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "File handling" : "Fayl emalı",
    "Maximum upload size" : "Maksimal yükləmə həcmi",
    "max. possible: " : "maks. ola bilər: ",
    "Save" : "Saxlamaq",
    "Settings" : "Quraşdırmalar",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Bu ünvanı <a href=\"%s\" target=\"_blank\">WebDAV vasitəsilə fayllarınızı əldə etmək üçün</a> istifadə edə bilərsiniz. ",
    "Cancel upload" : "Yüklənməni dayandır",
    "No files in here" : "Burda fayl yoxdur",
    "Upload some content or sync with your devices!" : "Bezi kontenti yüklə yada, öz avadanlıqlarınızla sinxronizasiya edin!",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Select all" : "Hamısıı seç",
    "Upload too large" : "Yüklənmə şox böyükdür",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yükləmək istədiyiniz faylların həcmi, bu serverdə izin verilmiş maksimal yüklənmə həcmindən böyükdür.",
    "No favorites" : "Seçilmiş yoxdur",
    "Files and folders you mark as favorite will show up here" : "İstəkli qeyd etdiyiniz fayllar və qovluqlar burda göstəriləcək",
    "Text file" : "Tekst faylı",
    "New text file.txt" : "Yeni mətn file.txt"
},
"nplurals=2; plural=(n != 1);");
